// Generated by gmmproc 2.50.0 -- DO NOT MODIFY!


#include <glibmm.h>

#include <gtkmm/aspectframe.h>
#include <gtkmm/private/aspectframe_p.h>


/*
 * Copyright 1998-2002 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <gtk/gtk.h>

namespace
{
} // anonymous namespace


namespace Glib
{

Gtk::AspectFrame* wrap(GtkAspectFrame* object, bool take_copy)
{
  return dynamic_cast<Gtk::AspectFrame *> (Glib::wrap_auto ((GObject*)(object), take_copy));
}

} /* namespace Glib */

namespace Gtk
{


/* The *_Class implementation: */

const Glib::Class& AspectFrame_Class::init()
{
  if(!gtype_) // create the GType if necessary
  {
    // Glib::Class has to know the class init function to clone custom types.
    class_init_func_ = &AspectFrame_Class::class_init_function;

    // This is actually just optimized away, apparently with no harm.
    // Make sure that the parent type has been created.
    //CppClassParent::CppObjectType::get_type();

    // Create the wrapper type, with the same class/instance size as the base type.
    register_derived_type(gtk_aspect_frame_get_type());

    // Add derived versions of interfaces, if the C type implements any interfaces:

  }

  return *this;
}


void AspectFrame_Class::class_init_function(void* g_class, void* class_data)
{
  const auto klass = static_cast<BaseClassType*>(g_class);
  CppClassParent::class_init_function(klass, class_data);


}


Glib::ObjectBase* AspectFrame_Class::wrap_new(GObject* o)
{
  return manage(new AspectFrame((GtkAspectFrame*)(o)));

}


/* The implementation: */

AspectFrame::AspectFrame(const Glib::ConstructParams& construct_params)
:
  Gtk::Frame(construct_params)
{
  }

AspectFrame::AspectFrame(GtkAspectFrame* castitem)
:
  Gtk::Frame((GtkFrame*)(castitem))
{
  }


AspectFrame::AspectFrame(AspectFrame&& src) noexcept
: Gtk::Frame(std::move(src))
{}

AspectFrame& AspectFrame::operator=(AspectFrame&& src) noexcept
{
  Gtk::Frame::operator=(std::move(src));
  return *this;
}

AspectFrame::~AspectFrame() noexcept
{
  destroy_();
}

AspectFrame::CppClassType AspectFrame::aspectframe_class_; // initialize static member

GType AspectFrame::get_type()
{
  return aspectframe_class_.init().get_type();
}


GType AspectFrame::get_base_type()
{
  return gtk_aspect_frame_get_type();
}


AspectFrame::AspectFrame(const Glib::ustring& label, Align xalign, Align yalign, float ratio, bool obey_child)
:
  // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gtk::Frame(Glib::ConstructParams(aspectframe_class_.init(), "label", label.c_str(), "xalign", _gtkmm_align_float_from_enum(xalign), "yalign", _gtkmm_align_float_from_enum(yalign), "ratio", ratio, "obey_child", static_cast<int>(obey_child), nullptr))
{
  

}

AspectFrame::AspectFrame(const Glib::ustring& label, float xalign, float yalign, float ratio, bool obey_child)
:
  // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gtk::Frame(Glib::ConstructParams(aspectframe_class_.init(), "label", label.c_str(), "xalign", xalign, "yalign", yalign, "ratio", ratio, "obey_child", static_cast<int>(obey_child), nullptr))
{
  

}

void AspectFrame::set(float xalign, float yalign, float ratio, bool obey_child)
{
  gtk_aspect_frame_set(gobj(), xalign, yalign, ratio, static_cast<int>(obey_child));
}

void AspectFrame::set(Align xalign, Align yalign, float ratio, bool obey_child)
{
  gtk_aspect_frame_set(gobj(), _gtkmm_align_float_from_enum(xalign), _gtkmm_align_float_from_enum(yalign), ratio, static_cast<int>(obey_child));
}


Glib::PropertyProxy< float > AspectFrame::property_xalign() 
{
  return Glib::PropertyProxy< float >(this, "xalign");
}

Glib::PropertyProxy_ReadOnly< float > AspectFrame::property_xalign() const
{
  return Glib::PropertyProxy_ReadOnly< float >(this, "xalign");
}

Glib::PropertyProxy< float > AspectFrame::property_yalign() 
{
  return Glib::PropertyProxy< float >(this, "yalign");
}

Glib::PropertyProxy_ReadOnly< float > AspectFrame::property_yalign() const
{
  return Glib::PropertyProxy_ReadOnly< float >(this, "yalign");
}

Glib::PropertyProxy< float > AspectFrame::property_ratio() 
{
  return Glib::PropertyProxy< float >(this, "ratio");
}

Glib::PropertyProxy_ReadOnly< float > AspectFrame::property_ratio() const
{
  return Glib::PropertyProxy_ReadOnly< float >(this, "ratio");
}

Glib::PropertyProxy< bool > AspectFrame::property_obey_child() 
{
  return Glib::PropertyProxy< bool >(this, "obey-child");
}

Glib::PropertyProxy_ReadOnly< bool > AspectFrame::property_obey_child() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "obey-child");
}


} // namespace Gtk


