// Generated by gmmproc 2.50.0 -- DO NOT MODIFY!


#include <glibmm.h>

#include <gtkmm/combobox.h>
#include <gtkmm/private/combobox_p.h>


/*
 * Copyright 2003 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <gtkmm/liststore.h>
#include <gtkmm/cellrenderertext.h>
#include <gtkmm/treeview_private.h> //For SignalProxy_RowSeparator.
#include <gtk/gtk.h>

namespace Gtk
{

ComboBox::ComboBox(bool has_entry)
:
  // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gtk::Bin(Glib::ConstructParams(combobox_class_.init(), "has-entry",gboolean(has_entry), nullptr))
{}

ComboBox::ComboBox(const Glib::RefPtr<TreeModel>& model, bool has_entry)
:
  // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gtk::Bin(Glib::ConstructParams(combobox_class_.init(), "model",Glib::unwrap(model),"has-entry",gboolean(has_entry), nullptr))
{}

ComboBox::ComboBox(const Glib::RefPtr<CellArea>& cell_area, bool has_entry)
:
  // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gtk::Bin(Glib::ConstructParams(combobox_class_.init(), "cell-area",Glib::unwrap(cell_area),"has-entry",gboolean(has_entry), nullptr))
{}

void ComboBox::unset_active()
{
  gtk_combo_box_set_active(gobj(), -1 /* see GTK+ docs */);
}

TreeModel::iterator ComboBox::get_active()
{
  Gtk::TreeModel::iterator iter;

  auto model = get_model();
  if(model)
  {
    gtk_combo_box_get_active_iter(gobj(), iter.gobj());

    //It must be given the model, because the C++ wrapper has extra information.
    iter.set_model_gobject(model->gobj());
  }

  return iter;
}

TreeModel::const_iterator ComboBox::get_active() const
{
  Gtk::TreeModel::iterator iter;

  const auto model = get_model();
  if(model)
  {
    gtk_combo_box_get_active_iter(const_cast<GtkComboBox*>(gobj()), iter.gobj());

    //It must be given the model, because the C++ wrapper has extra information.
    iter.set_model_gobject(const_cast<GtkTreeModel*>(model->gobj()));
  }

  return iter;
}


void ComboBox::unset_model()
{
  gtk_combo_box_set_model(gobj(), nullptr);
}


void ComboBox::set_row_separator_func(const SlotRowSeparator& slot)
{
  //Create a copy of the slot. A pointer to this will be passed through the callback's data parameter.
  //It will be deleted when SignalProxy_RowSeparator_gtk_callback_destroy() is called.
  auto slot_copy = new SlotRowSeparator(slot);

  gtk_combo_box_set_row_separator_func(gobj(),
      &TreeView_Private::SignalProxy_RowSeparator_gtk_callback, slot_copy,
      &TreeView_Private::SignalProxy_RowSeparator_gtk_callback_destroy);
}

void ComboBox::unset_row_separator_func()
{
  gtk_combo_box_set_row_separator_func(gobj(), nullptr, nullptr, nullptr /* See C docs. */);
}

Entry* ComboBox::get_entry()
{
  auto widget = Glib::wrap(gtk_bin_get_child(GTK_BIN(gobj())));
  return dynamic_cast<Gtk::Entry*>(widget);
}

const Entry* ComboBox::get_entry() const
{
  const auto widget = Glib::wrap(gtk_bin_get_child(GTK_BIN(gobj())));
  return dynamic_cast<const Gtk::Entry*>(widget);
}

Glib::ustring ComboBox::get_entry_text() const
{
  const auto entry = get_entry();
  if(!entry)
    return Glib::ustring();
  else
    return entry->get_text();
}

// GtkComboBox:focus-on-click has been removed from gtk+.
// TODO: At ABI-break, remove it from gtkmm.
#ifndef GTKMM_DISABLE_DEPRECATED
Glib::PropertyProxy< bool > ComboBox::property_focus_on_click()
{
  return Glib::PropertyProxy< bool >(this, "focus-on-click");
}

Glib::PropertyProxy_ReadOnly< bool > ComboBox::property_focus_on_click() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "focus-on-click");
}
#endif // GTKMM_DISABLE_DEPRECATED

} // namespace Gtk

namespace
{


static const Glib::SignalProxyInfo ComboBox_signal_changed_info =
{
  "changed",
  (GCallback) &Glib::SignalProxyNormal::slot0_void_callback,
  (GCallback) &Glib::SignalProxyNormal::slot0_void_callback
};


static gchar* ComboBox_signal_format_entry_text_callback(GtkComboBox* self, const gchar* p0,void* data)
{
  using namespace Gtk;
  using SlotType = sigc::slot< Glib::ustring,const TreeModel::Path& >;

  auto obj = dynamic_cast<ComboBox*>(Glib::ObjectBase::_get_current_wrapper((GObject*) self));
  // Do not try to call a signal on a disassociated wrapper.
  if(obj)
  {
    try
    {
      if(const auto slot = Glib::SignalProxyNormal::data_to_slot(data))
        return g_strdup(((*static_cast<SlotType*>(slot))(TreeModel::Path(p0)
)).c_str());
    }
    catch(...)
    {
       Glib::exception_handlers_invoke();
    }
  }

  using RType = gchar*;
  return RType();
}

static gchar* ComboBox_signal_format_entry_text_notify_callback(GtkComboBox* self, const gchar* p0, void* data)
{
  using namespace Gtk;
  using SlotType = sigc::slot< void,const TreeModel::Path& >;

  auto obj = dynamic_cast<ComboBox*>(Glib::ObjectBase::_get_current_wrapper((GObject*) self));
  // Do not try to call a signal on a disassociated wrapper.
  if(obj)
  {
    try
    {
      if(const auto slot = Glib::SignalProxyNormal::data_to_slot(data))
        (*static_cast<SlotType*>(slot))(TreeModel::Path(p0)
);
    }
    catch(...)
    {
      Glib::exception_handlers_invoke();
    }
  }

  using RType = gchar*;
  return RType();
}

static const Glib::SignalProxyInfo ComboBox_signal_format_entry_text_info =
{
  "format-entry-text",
  (GCallback) &ComboBox_signal_format_entry_text_callback,
  (GCallback) &ComboBox_signal_format_entry_text_notify_callback
};


} // anonymous namespace


namespace Glib
{

Gtk::ComboBox* wrap(GtkComboBox* object, bool take_copy)
{
  return dynamic_cast<Gtk::ComboBox *> (Glib::wrap_auto ((GObject*)(object), take_copy));
}

} /* namespace Glib */

namespace Gtk
{


/* The *_Class implementation: */

const Glib::Class& ComboBox_Class::init()
{
  if(!gtype_) // create the GType if necessary
  {
    // Glib::Class has to know the class init function to clone custom types.
    class_init_func_ = &ComboBox_Class::class_init_function;

    // This is actually just optimized away, apparently with no harm.
    // Make sure that the parent type has been created.
    //CppClassParent::CppObjectType::get_type();

    // Create the wrapper type, with the same class/instance size as the base type.
    register_derived_type(gtk_combo_box_get_type());

    // Add derived versions of interfaces, if the C type implements any interfaces:
  CellLayout::add_interface(get_type());
  CellEditable::add_interface(get_type());

  }

  return *this;
}


void ComboBox_Class::class_init_function(void* g_class, void* class_data)
{
  const auto klass = static_cast<BaseClassType*>(g_class);
  CppClassParent::class_init_function(klass, class_data);


  klass->changed = &changed_callback;
}


void ComboBox_Class::changed_callback(GtkComboBox* self)
{
  const auto obj_base = static_cast<Glib::ObjectBase*>(
      Glib::ObjectBase::_get_current_wrapper((GObject*)self));

  // Non-gtkmmproc-generated custom classes implicitly call the default
  // Glib::ObjectBase constructor, which sets is_derived_. But gtkmmproc-
  // generated classes can use this optimisation, which avoids the unnecessary
  // parameter conversions if there is no possibility of the virtual function
  // being overridden:
  if(obj_base && obj_base->is_derived_())
  {
    const auto obj = dynamic_cast<CppObjectType* const>(obj_base);
    if(obj) // This can be NULL during destruction.
    {
      try // Trap C++ exceptions which would normally be lost because this is a C callback.
      {
        // Call the virtual member method, which derived classes might override.
        obj->on_changed();
        return;
      }
      catch(...)
      {
        Glib::exception_handlers_invoke();
      }
    }
  }

  const auto base = static_cast<BaseClassType*>(
        g_type_class_peek_parent(G_OBJECT_GET_CLASS(self)) // Get the parent class of the object class (The original underlying C class).
    );

  // Call the original underlying C function:
  if(base && base->changed)
    (*base->changed)(self);
}


Glib::ObjectBase* ComboBox_Class::wrap_new(GObject* o)
{
  return manage(new ComboBox((GtkComboBox*)(o)));

}


/* The implementation: */

ComboBox::ComboBox(const Glib::ConstructParams& construct_params)
:
  Gtk::Bin(construct_params)
{
  }

ComboBox::ComboBox(GtkComboBox* castitem)
:
  Gtk::Bin((GtkBin*)(castitem))
{
  }


ComboBox::ComboBox(ComboBox&& src) noexcept
: Gtk::Bin(std::move(src))
  , CellLayout(std::move(src))
  , CellEditable(std::move(src))
{}

ComboBox& ComboBox::operator=(ComboBox&& src) noexcept
{
  Gtk::Bin::operator=(std::move(src));
  CellLayout::operator=(std::move(src));
  CellEditable::operator=(std::move(src));
  return *this;
}

ComboBox::~ComboBox() noexcept
{
  destroy_();
}

ComboBox::CppClassType ComboBox::combobox_class_; // initialize static member

GType ComboBox::get_type()
{
  return combobox_class_.init().get_type();
}


GType ComboBox::get_base_type()
{
  return gtk_combo_box_get_type();
}


void ComboBox::set_wrap_width(int width)
{
  gtk_combo_box_set_wrap_width(gobj(), width);
}

int ComboBox::get_wrap_width() const
{
  return gtk_combo_box_get_wrap_width(const_cast<GtkComboBox*>(gobj()));
}

void ComboBox::set_row_span_column(int row_span)
{
  gtk_combo_box_set_row_span_column(gobj(), row_span);
}

int ComboBox::get_row_span_column() const
{
  return gtk_combo_box_get_row_span_column(const_cast<GtkComboBox*>(gobj()));
}

void ComboBox::set_column_span_column(int column_span)
{
  gtk_combo_box_set_column_span_column(gobj(), column_span);
}

int ComboBox::get_column_span_column() const
{
  return gtk_combo_box_get_column_span_column(const_cast<GtkComboBox*>(gobj()));
}

#ifndef GTKMM_DISABLE_DEPRECATED
G_GNUC_BEGIN_IGNORE_DEPRECATIONS
bool ComboBox::get_add_tearoffs() const
{
  return gtk_combo_box_get_add_tearoffs(const_cast<GtkComboBox*>(gobj()));
}
G_GNUC_END_IGNORE_DEPRECATIONS
#endif // GTKMM_DISABLE_DEPRECATED

#ifndef GTKMM_DISABLE_DEPRECATED
G_GNUC_BEGIN_IGNORE_DEPRECATIONS
void ComboBox::set_add_tearoffs(bool add_tearoffs)
{
  gtk_combo_box_set_add_tearoffs(gobj(), static_cast<int>(add_tearoffs));
}
G_GNUC_END_IGNORE_DEPRECATIONS
#endif // GTKMM_DISABLE_DEPRECATED

#ifndef GTKMM_DISABLE_DEPRECATED
G_GNUC_BEGIN_IGNORE_DEPRECATIONS
Glib::ustring ComboBox::get_title() const
{
  return Glib::convert_const_gchar_ptr_to_ustring(gtk_combo_box_get_title(const_cast<GtkComboBox*>(gobj())));
}
G_GNUC_END_IGNORE_DEPRECATIONS
#endif // GTKMM_DISABLE_DEPRECATED

#ifndef GTKMM_DISABLE_DEPRECATED
G_GNUC_BEGIN_IGNORE_DEPRECATIONS
void ComboBox::set_title(const Glib::ustring& title)
{
  gtk_combo_box_set_title(gobj(), title.c_str());
}
G_GNUC_END_IGNORE_DEPRECATIONS
#endif // GTKMM_DISABLE_DEPRECATED

#ifndef GTKMM_DISABLE_DEPRECATED
G_GNUC_BEGIN_IGNORE_DEPRECATIONS
bool ComboBox::get_focus_on_click() const
{
  return gtk_combo_box_get_focus_on_click(const_cast<GtkComboBox*>(gobj()));
}
G_GNUC_END_IGNORE_DEPRECATIONS
#endif // GTKMM_DISABLE_DEPRECATED

#ifndef GTKMM_DISABLE_DEPRECATED
G_GNUC_BEGIN_IGNORE_DEPRECATIONS
void ComboBox::set_focus_on_click(bool focus_on_click)
{
  gtk_combo_box_set_focus_on_click(gobj(), static_cast<int>(focus_on_click));
}
G_GNUC_END_IGNORE_DEPRECATIONS
#endif // GTKMM_DISABLE_DEPRECATED

int ComboBox::get_active_row_number() const
{
  return gtk_combo_box_get_active(const_cast<GtkComboBox*>(gobj()));
}

void ComboBox::set_active(int index)
{
  gtk_combo_box_set_active(gobj(), index);
}

void ComboBox::set_active(const TreeModel::iterator& iter)
{
  gtk_combo_box_set_active_iter(gobj(), const_cast<GtkTreeIter*>((iter).gobj()));
}

Glib::RefPtr<TreeModel> ComboBox::get_model()
{
  Glib::RefPtr<TreeModel> retvalue = Glib::wrap(gtk_combo_box_get_model(gobj()));
  if(retvalue)
    retvalue->reference(); //The function does not do a ref for us.
  return retvalue;
}

Glib::RefPtr<const TreeModel> ComboBox::get_model() const
{
  return const_cast<ComboBox*>(this)->get_model();
}

void ComboBox::set_model(const Glib::RefPtr<TreeModel>& model)
{
  gtk_combo_box_set_model(gobj(), Glib::unwrap(model));
}

void ComboBox::set_button_sensitivity(SensitivityType sensitivity)
{
  gtk_combo_box_set_button_sensitivity(gobj(), ((GtkSensitivityType)(sensitivity)));
}

SensitivityType ComboBox::get_button_sensitivity() const
{
  return ((SensitivityType)(gtk_combo_box_get_button_sensitivity(const_cast<GtkComboBox*>(gobj()))));
}

bool ComboBox::get_has_entry() const
{
  return gtk_combo_box_get_has_entry(const_cast<GtkComboBox*>(gobj()));
}

void ComboBox::set_entry_text_column(const TreeModelColumnBase& text_column) const
{
  gtk_combo_box_set_entry_text_column(const_cast<GtkComboBox*>(gobj()), (text_column).index());
}

void ComboBox::set_entry_text_column(int text_column)
{
  gtk_combo_box_set_entry_text_column(gobj(), text_column);
}

int ComboBox::get_entry_text_column() const
{
  return gtk_combo_box_get_entry_text_column(const_cast<GtkComboBox*>(gobj()));
}

void ComboBox::set_popup_fixed_width(bool fixed)
{
  gtk_combo_box_set_popup_fixed_width(gobj(), static_cast<int>(fixed));
}

bool ComboBox::get_popup_fixed_width() const
{
  return gtk_combo_box_get_popup_fixed_width(const_cast<GtkComboBox*>(gobj()));
}

void ComboBox::popup()
{
  gtk_combo_box_popup(gobj());
}

void ComboBox::popup(const Glib::RefPtr<Gdk::Device>& device)
{
  gtk_combo_box_popup_for_device(gobj(), Glib::unwrap(device));
}

void ComboBox::popdown()
{
  gtk_combo_box_popdown(gobj());
}

#ifdef GTKMM_ATKMM_ENABLED
Glib::RefPtr<Atk::Object> ComboBox::get_popup_accessible()
{
  return Glib::wrap(gtk_combo_box_get_popup_accessible(gobj()));
}
#endif // GTKMM_ATKMM_ENABLED

#ifdef GTKMM_ATKMM_ENABLED
Glib::RefPtr<const Atk::Object> ComboBox::get_popup_accessible() const
{
  return const_cast<ComboBox*>(this)->get_popup_accessible();
}
#endif // GTKMM_ATKMM_ENABLED

int ComboBox::get_id_column() const
{
  return gtk_combo_box_get_id_column(const_cast<GtkComboBox*>(gobj()));
}

void ComboBox::set_id_column(int id_column)
{
  gtk_combo_box_set_id_column(gobj(), id_column);
}

Glib::ustring ComboBox::get_active_id() const
{
  return Glib::convert_const_gchar_ptr_to_ustring(gtk_combo_box_get_active_id(const_cast<GtkComboBox*>(gobj())));
}

#ifndef GTKMM_DISABLE_DEPRECATED
G_GNUC_BEGIN_IGNORE_DEPRECATIONS
void ComboBox::get_active_id(const Glib::ustring& active_id)
{
  gtk_combo_box_set_active_id(gobj(), active_id.c_str());
}
G_GNUC_END_IGNORE_DEPRECATIONS
#endif // GTKMM_DISABLE_DEPRECATED

bool ComboBox::set_active_id(const Glib::ustring& active_id)
{
  return gtk_combo_box_set_active_id(gobj(), active_id.c_str());
}


Glib::SignalProxy< void > ComboBox::signal_changed()
{
  return Glib::SignalProxy< void >(this, &ComboBox_signal_changed_info);
}


Glib::SignalProxy< Glib::ustring,const TreeModel::Path& > ComboBox::signal_format_entry_text()
{
  return Glib::SignalProxy< Glib::ustring,const TreeModel::Path& >(this, &ComboBox_signal_format_entry_text_info);
}


Glib::PropertyProxy< Glib::RefPtr<TreeModel> > ComboBox::property_model() 
{
  return Glib::PropertyProxy< Glib::RefPtr<TreeModel> >(this, "model");
}

Glib::PropertyProxy_ReadOnly< Glib::RefPtr<TreeModel> > ComboBox::property_model() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::RefPtr<TreeModel> >(this, "model");
}

Glib::PropertyProxy< int > ComboBox::property_wrap_width() 
{
  return Glib::PropertyProxy< int >(this, "wrap-width");
}

Glib::PropertyProxy_ReadOnly< int > ComboBox::property_wrap_width() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "wrap-width");
}

Glib::PropertyProxy< int > ComboBox::property_row_span_column() 
{
  return Glib::PropertyProxy< int >(this, "row-span-column");
}

Glib::PropertyProxy_ReadOnly< int > ComboBox::property_row_span_column() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "row-span-column");
}

Glib::PropertyProxy< int > ComboBox::property_column_span_column() 
{
  return Glib::PropertyProxy< int >(this, "column-span-column");
}

Glib::PropertyProxy_ReadOnly< int > ComboBox::property_column_span_column() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "column-span-column");
}

Glib::PropertyProxy< int > ComboBox::property_active() 
{
  return Glib::PropertyProxy< int >(this, "active");
}

Glib::PropertyProxy_ReadOnly< int > ComboBox::property_active() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "active");
}

#ifndef GTKMM_DISABLE_DEPRECATED

Glib::PropertyProxy< bool > ComboBox::property_add_tearoffs() 
{
  return Glib::PropertyProxy< bool >(this, "add-tearoffs");
}
#endif // GTKMM_DISABLE_DEPRECATED


#ifndef GTKMM_DISABLE_DEPRECATED

Glib::PropertyProxy_ReadOnly< bool > ComboBox::property_add_tearoffs() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "add-tearoffs");
}
#endif // GTKMM_DISABLE_DEPRECATED


Glib::PropertyProxy< bool > ComboBox::property_has_frame() 
{
  return Glib::PropertyProxy< bool >(this, "has-frame");
}

Glib::PropertyProxy_ReadOnly< bool > ComboBox::property_has_frame() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "has-frame");
}

#ifndef GTKMM_DISABLE_DEPRECATED

Glib::PropertyProxy< Glib::ustring > ComboBox::property_tearoff_title() 
{
  return Glib::PropertyProxy< Glib::ustring >(this, "tearoff-title");
}
#endif // GTKMM_DISABLE_DEPRECATED


#ifndef GTKMM_DISABLE_DEPRECATED

Glib::PropertyProxy_ReadOnly< Glib::ustring > ComboBox::property_tearoff_title() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::ustring >(this, "tearoff-title");
}
#endif // GTKMM_DISABLE_DEPRECATED


Glib::PropertyProxy_ReadOnly< bool > ComboBox::property_popup_shown() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "popup-shown");
}

Glib::PropertyProxy< SensitivityType > ComboBox::property_button_sensitivity() 
{
  return Glib::PropertyProxy< SensitivityType >(this, "button-sensitivity");
}

Glib::PropertyProxy_ReadOnly< SensitivityType > ComboBox::property_button_sensitivity() const
{
  return Glib::PropertyProxy_ReadOnly< SensitivityType >(this, "button-sensitivity");
}

Glib::PropertyProxy< bool > ComboBox::property_popup_fixed_width() 
{
  return Glib::PropertyProxy< bool >(this, "popup-fixed-width");
}

Glib::PropertyProxy_ReadOnly< bool > ComboBox::property_popup_fixed_width() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "popup-fixed-width");
}

Glib::PropertyProxy_ReadOnly< Glib::RefPtr<CellArea> > ComboBox::property_cell_area() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::RefPtr<CellArea> >(this, "cell-area");
}

Glib::PropertyProxy_ReadOnly< bool > ComboBox::property_has_entry() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "has-entry");
}

Glib::PropertyProxy< int > ComboBox::property_entry_text_column() 
{
  return Glib::PropertyProxy< int >(this, "entry-text-column");
}

Glib::PropertyProxy_ReadOnly< int > ComboBox::property_entry_text_column() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "entry-text-column");
}

Glib::PropertyProxy< int > ComboBox::property_id_column() 
{
  return Glib::PropertyProxy< int >(this, "id-column");
}

Glib::PropertyProxy_ReadOnly< int > ComboBox::property_id_column() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "id-column");
}

Glib::PropertyProxy< Glib::ustring > ComboBox::property_active_id() 
{
  return Glib::PropertyProxy< Glib::ustring >(this, "active-id");
}

Glib::PropertyProxy_ReadOnly< Glib::ustring > ComboBox::property_active_id() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::ustring >(this, "active-id");
}


void Gtk::ComboBox::on_changed()
{
  const auto base = static_cast<BaseClassType*>(
      g_type_class_peek_parent(G_OBJECT_GET_CLASS(gobject_)) // Get the parent class of the object class (The original underlying C class).
  );

  if(base && base->changed)
    (*base->changed)(gobj());
}


} // namespace Gtk


