// Generated by gmmproc 2.50.0 -- DO NOT MODIFY!
#ifndef _GTKMM_ACTIONBAR_H
#define _GTKMM_ACTIONBAR_H


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

/*
 * Copyright (C) 2013 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <gtkmm/bin.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
using GtkActionBar = struct _GtkActionBar;
using GtkActionBarClass = struct _GtkActionBarClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gtk
{ class ActionBar_Class; } // namespace Gtk
#endif //DOXYGEN_SHOULD_SKIP_THIS

namespace Gtk
{

/** A full width bar for presenting contextual actions.
 *
 * ActionBar is designed to present contextual actions. It is
 * expected to be displayed below the content and expand horizontally
 * to fill the area.
 *
 * It allows placing children at the start or the end. In addition, it
 * contains an internal centered box which is centered with respect to
 * the full width of the box, even if the children at either side take
 * up different amounts of space.
 *
 * @see Box
 * @ingroup Widgets
 * @newin{3,12}
 */

class ActionBar
  : public Bin
{
  public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  typedef ActionBar CppObjectType;
  typedef ActionBar_Class CppClassType;
  typedef GtkActionBar BaseObjectType;
  typedef GtkActionBarClass BaseClassType;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  ActionBar(ActionBar&& src) noexcept;
  ActionBar& operator=(ActionBar&& src) noexcept;

  // noncopyable
  ActionBar(const ActionBar&) = delete;
  ActionBar& operator=(const ActionBar&) = delete;

  ~ActionBar() noexcept override;

#ifndef DOXYGEN_SHOULD_SKIP_THIS

private:
  friend class ActionBar_Class;
  static CppClassType actionbar_class_;

protected:
  explicit ActionBar(const Glib::ConstructParams& construct_params);
  explicit ActionBar(GtkActionBar* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GtkObject.
  GtkActionBar*       gobj()       { return reinterpret_cast<GtkActionBar*>(gobject_); }

  ///Provides access to the underlying C GtkObject.
  const GtkActionBar* gobj() const { return reinterpret_cast<GtkActionBar*>(gobject_); }


public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


private:

public:

  /** Creates a new ActionBar widget.
   */
  ActionBar();

  
  /** Adds @a child to @a action_bar, packed with reference to the
   * start of the @a action_bar.
   * 
   * @newin{3,12}
   * 
   * @param child The Gtk::Widget to be added to @a action_bar.
   */
  void pack_start(Gtk::Widget& child);
  
  /** Adds @a child to @a action_bar, packed with reference to the
   * end of the @a action_bar.
   * 
   * @newin{3,12}
   * 
   * @param child The Gtk::Widget to be added to @a action_bar.
   */
  void pack_end(Gtk::Widget& child);

  // transfer none
  
  /** Retrieves the center bar widget of the bar.
   * 
   * @newin{3,12}
   * 
   * @return The center Gtk::Widget or <tt>nullptr</tt>.
   */
  Widget* get_center_widget();
  
  /** Retrieves the center bar widget of the bar.
   * 
   * @newin{3,12}
   * 
   * @return The center Gtk::Widget or <tt>nullptr</tt>.
   */
  const Widget* get_center_widget() const;
  
  /** Sets the center widget for the Gtk::ActionBar.
   * 
   * @newin{3,12}
   * 
   * @param center_widget A widget to use for the center.
   */
  void set_center_widget(Widget& center_widget);

  /** Unset the center widget.
   *
   * See set_center_widget().
   */
  void unset_center_widget();

  // Gtk::ActionBar has no properties, signals nor vfuncs as of 3.12.


};

} // namespace Gtk


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::ActionBar
   */
  Gtk::ActionBar* wrap(GtkActionBar* object, bool take_copy = false);
} //namespace Glib


#endif /* _GTKMM_ACTIONBAR_H */

